@@ -5,7 +5,7 @@ use warnings;
 use FindBin;
 use lib "$FindBin::Bin/../../lib";
 use Net::OAuth::LP;
-use Data::Dumper;
+use Data::Dump qw(pp);
 use File::Spec::Functions;
 
 my $client = Net::OAuth::LP->new(consumer_key => 'fwapfwap');
@@ -13,5 +13,5 @@ my $client = Net::OAuth::LP->new(consumer_key => 'fwapfwap');
 $client->staging(1);
 $client->login_with_creds;
 
-print $client->dump;
+pp $client;
 
