@@ -1,22 +1,23 @@
 package Net::OAuth::LP::Models::Bug;
 
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use Moo;
+use Types::Standard qw(Str Int ArrayRef HashRef);
 use Method::Signatures;
 
 with('Net::OAuth::LP::Models');
 
 has 'bug' => (
     is      => 'rw',
-    isa     => method {},
+    isa     => HashRef,
     lazy    => 1,
     default => method { {} },
 );
 
 has 'tasks' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => HashRef,
     lazy    => 1,
     default => method {
         $self->get($self->bug->{bug_tasks_collection_link});
@@ -25,7 +26,7 @@ has 'tasks' => (
 
 has 'activity' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => HashRef,
     lazy    => 1,
     default => method {
         $self->get($self->bug->{activity_collection_link});
@@ -34,7 +35,7 @@ has 'activity' => (
 
 has 'attachments' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => HashRef,
     lazy    => 1,
     default => method {
         $self->get($self->bug->{attachments_collection_link});
@@ -43,7 +44,7 @@ has 'attachments' => (
 
 has 'watches' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => HashRef,
     lazy    => 1,
     default => method {
         $self->get($self->bug->{bug_watches_collection_link});
@@ -61,7 +62,7 @@ has 'can_expire' => (
 
 has 'cves' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => HashRef,
     lazy    => 1,
     default => method {
         $self->get($self->bug->{cves_collection_link});
@@ -70,7 +71,7 @@ has 'cves' => (
 
 has 'description' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => Str,
     lazy    => 1,
     default => method {
         $self->bug->{description};
@@ -79,7 +80,7 @@ has 'description' => (
 
 has 'heat' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => Int,
     lazy    => 1,
     default => method {
         $self->bug->{heat};
@@ -88,7 +89,7 @@ has 'heat' => (
 
 has 'information_type' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => Str,
     lazy    => 1,
     default => method {
         $self->bug->{information_type};
@@ -96,8 +97,8 @@ has 'information_type' => (
 );
 
 has 'branches' => (
-    is => 'ro',
-    isa     => method {},
+    is      => 'ro',
+    isa     => HashRef,
     lazy    => 1,
     default => method {
         self->get($self->bug->{linked_branches_collection_link});
@@ -106,7 +107,7 @@ has 'branches' => (
 
 has 'owner' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => HashRef,
     lazy    => 1,
     default => method {
         $self->get($self->bug->{owner_link});
@@ -115,7 +116,7 @@ has 'owner' => (
 
 has 'title' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => Str,
     lazy    => 1,
     default => method {
         $self->bug->{title};
@@ -124,7 +125,7 @@ has 'title' => (
 
 has 'tags' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => ArrayRef,
     lazy    => 1,
     default => method {
         $self->bug->{tags};
@@ -133,7 +134,7 @@ has 'tags' => (
 
 has 'id' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => Int,
     lazy    => 1,
     default => method {
         $self->bug->{id};
@@ -142,38 +143,48 @@ has 'id' => (
 
 has 'web_link' => (
     is      => 'ro',
-    isa     => method {},
+    isa     => Str,
     lazy    => 1,
     default => method {
         $self->bug->{web_link};
     },
 );
 
+has 'self_link' => (
+    is      => 'ro',
+    isa     => Str,
+    lazy    => 1,
+    default => method {
+        $self->bug->{self_link};
+    },
+);
+
 method find ($bug_id) {
     my $resource_link = $self->__path_cons("bugs/$bug_id");
     $self->bug($self->get($resource_link));
 }
 
 method set_tags ($tags) {
-    $self->update($self->bug->{self_link}, {'tags' => $tags});
+    $self->update($self->self_link, {'tags' => $tags});
 }
 
 method set_title ($title) {
-    $self->update($self->bug->{self_link}, {'title' => $title});
+    $self->update($self->self_link, {'title' => $title});
 }
 
 method set_assignee ($assignee) {
     $self->update($self->bug->tasks->{self_link},
-        {'assignee_link' => $assignee->{self_link}});
+        {'assignee_link' => $assignee->self_link});
 }
 
 method set_importance ($importance) {
-    $self->update($self->bug->tasks->{self_link}, {'importance' => $importance});
+    $self->update($self->bug->tasks->{self_link},
+        {'importance' => $importance});
 }
 
 method new_message ($msg) {
     $self->post(
-        $self->bug->{self_link},
+        $self->self_link,
         {   'ws.op'   => 'newMessage',
             'content' => $msg
         }
@@ -186,11 +197,51 @@ __END__
 
 =head1 NAME
 
-Net::OAuth::LP::Models::Bug
+Net::OAuth::LP::Models::Bug - Bug model
 
 =head1 DESCRIPTION
 
-Bug Model
+Interface to setting/retrieving bug information
+
+=head1 SYNOPSIS
+
+    my $b = Net::OAuth::LP::Models::Bug->new;
+    $b->find(1);
+    say $b->description;
+
+=head1 ATTRIBUTES
+
+=head2 B<activity>
+
+=head2 B<attachments>
+
+=head2 B<branches>
+
+=head2 B<bug>
+
+=head2 B<display_name>
+
+=head2 B<heat>
+
+=head2 B<id>
+
+=head2 B<information_type>
+
+=head2 B<name>
+
+=head2 B<owner>
+
+=head2 B<self_link>
+
+=head2 B<tags>
+
+=head2 B<tasks>
+
+=head2 B<title>
+
+=head2 B<watches>
+
+=head2 B<web_link>
 
 =head1 METHODS
 
@@ -198,50 +249,37 @@ Bug Model
 
     my $b = Net::OAuth::LP::Models::Bug->new;
 
-
 =head2 B<find>
 
-    my $bug = $b->find(1);
+    $b->find(1);
 
-=head2 B<bug_set_tags>
+=head2 B<set_tags>
 
-    $lp->bug_set_tags($bug, ['tagA', 'tagB']);
+    $b->set_tags(['tagA', 'tagB']);
 
-=head2 B<bug_set_title>
+=head2 B<set_title>
 
 Set title(aka summary) of bug
 
-    $lp->bug_set_title($bug, 'A new title');
+    $b->set_title('A new title');
 
-=head2 B<bug_new_message>
+=head2 B<new_message>
 
 Adds a new message to the bug.
 
-    $lp->bug_new_message($bug, "This is a comment");
+    $b->new_message("This is a comment");
 
-=head2 B<bug_activity>
-
-Views bug activity
-
-    $lp->bug_activity($resource_link);
-
-=head2 B<bug_task>
-
-View bug tasks
-
-    $lp->bug_task($resource);
-
-=head2 B<bug_set_importance>
+=head2 B<set_importance>
 
 Sets priority ['Critical', 'High', 'Medium', 'Low']
 
-    $lp->bug_set_importance($bug, 'Critical');
+    $b->set_importance('Critical');
 
-=head2 B<bug_set_assignee>
+=head2 B<set_assignee>
 
 Sets the assignee of bug.
 
-    my $person = $lp->person('~adam-stokes');
-    $lp->bug_set_assignee($bug, $person);
+    $person->find('~adam-stokes');
+    $b->set_assignee($person);
 
 =cut
